Getting started
=====

.. _installation:

Installation
------------

To use SPECTRAX, you can clone the repository
and install it using the following command:

.. code-block:: console

    $ git clone https://github.com/uwplasma/spectrax.git
    $ cd spectrax
    $ pip install .

Run an example
--------------

To run the main example, use the following command:

.. code-block:: console

    spectrax

More examples are in the `examples` folder.